# This file is auto-generated by AWSMetadata.jl
using AWS
using AWS.AWSServices: resource_groups
using AWS.Compat
using AWS.UUIDs

"""
    CreateGroup()

Creates a resource group with the specified name and description. You can optionally include a resource query, or a service configuration.

# Required Parameters
- `Name`: The name of the group, which is the identifier of the group in other operations. You can't change the name of a resource group after you create it. A resource group name can consist of letters, numbers, hyphens, periods, and underscores. The name cannot start with AWS or aws; these are reserved. A resource group name must be unique within each AWS Region in your AWS account.

# Optional Parameters
- `Configuration`: A configuration associates the resource group with an AWS service and specifies how the service can interact with the resources in the group. A configuration is an array of GroupConfigurationItem elements.  You can specify either a Configuration or a ResourceQuery in a group, but not both. 
- `Description`: The description of the resource group. Descriptions can consist of letters, numbers, hyphens, underscores, periods, and spaces.
- `ResourceQuery`: The resource query that determines which AWS resources are members of this group.  You can specify either a ResourceQuery or a Configuration, but not both. 
- `Tags`: The tags to add to the group. A tag is key-value pair string.
"""
create_group(Name; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/groups", Dict{String, Any}("Name"=>Name); aws_config=aws_config)
create_group(Name, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/groups", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Name"=>Name), args)); aws_config=aws_config)

"""
    DeleteGroup()

Deletes the specified resource group. Deleting a resource group does not delete any resources that are members of the group; it only deletes the group structure.

# Optional Parameters
- `Group`: The name or the ARN of the resource group to delete.
- `GroupName`: Don't use this parameter. Use Group instead.
"""
delete_group(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/delete-group"; aws_config=aws_config)
delete_group(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/delete-group", args; aws_config=aws_config)

"""
    GetGroup()

Returns information about a specified resource group.

# Optional Parameters
- `Group`: The name or the ARN of the resource group to retrieve.
- `GroupName`: Don't use this parameter. Use Group instead.
"""
get_group(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group"; aws_config=aws_config)
get_group(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group", args; aws_config=aws_config)

"""
    GetGroupConfiguration()

Returns the service configuration associated with the specified resource group. AWS Resource Groups supports configurations for the following resource group types:    AWS::EC2::CapacityReservationPool - Amazon EC2 capacity reservation pools. For more information, see Working with capacity reservation groups in the EC2 Users Guide.  

# Optional Parameters
- `Group`: The name or the ARN of the resource group.
"""
get_group_configuration(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group-configuration"; aws_config=aws_config)
get_group_configuration(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group-configuration", args; aws_config=aws_config)

"""
    GetGroupQuery()

Retrieves the resource query associated with the specified resource group.

# Optional Parameters
- `Group`: The name or the ARN of the resource group to query.
- `GroupName`: Don't use this parameter. Use Group instead.
"""
get_group_query(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group-query"; aws_config=aws_config)
get_group_query(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/get-group-query", args; aws_config=aws_config)

"""
    GetTags()

Returns a list of tags that are associated with a resource group, specified by an ARN.

# Required Parameters
- `Arn`: The ARN of the resource group whose tags you want to retrieve.

"""
get_tags(Arn; aws_config::AWSConfig=global_aws_config()) = resource_groups("GET", "/resources/$(Arn)/tags"; aws_config=aws_config)
get_tags(Arn, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("GET", "/resources/$(Arn)/tags", args; aws_config=aws_config)

"""
    GroupResources()

Adds the specified resources to the specified group.

# Required Parameters
- `Group`: The name or the ARN of the resource group to add resources to.
- `ResourceArns`: The list of ARNs for resources to be added to the group. 

"""
group_resources(Group, ResourceArns; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/group-resources", Dict{String, Any}("Group"=>Group, "ResourceArns"=>ResourceArns); aws_config=aws_config)
group_resources(Group, ResourceArns, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/group-resources", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Group"=>Group, "ResourceArns"=>ResourceArns), args)); aws_config=aws_config)

"""
    ListGroupResources()

Returns a list of ARNs of the resources that are members of a specified resource group.

# Optional Parameters
- `Filters`: Filters, formatted as ResourceFilter objects, that you want to apply to a ListGroupResources operation. Filters the results to include only those of the specified resource types.    resource-type - Filter resources by their type. Specify up to five resource types in the format AWS::ServiceCode::ResourceType. For example, AWS::EC2::Instance, or AWS::S3::Bucket.    When you specify a resource-type filter for ListGroupResources, AWS Resource Groups validates your filter resource types against the types that are defined in the query associated with the group. For example, if a group contains only S3 buckets because its query specifies only that resource type, but your resource-type filter includes EC2 instances, AWS Resource Groups does not filter for EC2 instances. In this case, a ListGroupResources request returns a BadRequestException error with a message similar to the following:  The resource types specified as filters in the request are not valid.  The error includes a list of resource types that failed the validation because they are not part of the query associated with the group. This validation doesn't occur when the group query specifies AWS::AllSupported, because a group based on such a query can contain any of the allowed resource types for the query type (tag-based or AWS CloudFormation stack-based queries).
- `Group`: The name or the ARN of the resource group
- `GroupName`: Don't use this parameter. Use Group instead.
- `MaxResults`: The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
- `NextToken`: The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
"""
list_group_resources(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/list-group-resources"; aws_config=aws_config)
list_group_resources(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/list-group-resources", args; aws_config=aws_config)

"""
    ListGroups()

Returns a list of existing resource groups in your account.

# Optional Parameters
- `Filters`: Filters, formatted as GroupFilter objects, that you want to apply to a ListGroups operation.    resource-type - Filter the results to include only those of the specified resource types. Specify up to five resource types in the format AWS::ServiceCode::ResourceType . For example, AWS::EC2::Instance, or AWS::S3::Bucket.    configuration-type - Filter the results to include only those groups that have the specified configuration types attached. The current supported values are:   AWS:EC2::CapacityReservationPool    
- `maxResults`: The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
- `nextToken`: The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
"""
list_groups(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/groups-list"; aws_config=aws_config)
list_groups(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/groups-list", args; aws_config=aws_config)

"""
    SearchResources()

Returns a list of AWS resource identifiers that matches the specified query. The query uses the same format as a resource query in a CreateGroup or UpdateGroupQuery operation.

# Required Parameters
- `ResourceQuery`: The search query, using the same formats that are supported for resource group definition. For more information, see CreateGroup.

# Optional Parameters
- `MaxResults`: The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
- `NextToken`: The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value provided by a previous call's NextToken response to indicate where the output should continue from.
"""
search_resources(ResourceQuery; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/resources/search", Dict{String, Any}("ResourceQuery"=>ResourceQuery); aws_config=aws_config)
search_resources(ResourceQuery, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/resources/search", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ResourceQuery"=>ResourceQuery), args)); aws_config=aws_config)

"""
    Tag()

Adds tags to a resource group with the specified ARN. Existing tags on a resource group are not changed if they are not specified in the request parameters.  Do not store personally identifiable information (PII) or other confidential or sensitive information in tags. We use tags to provide you with billing and administration services. Tags are not intended to be used for private or sensitive data. 

# Required Parameters
- `Arn`: The ARN of the resource group to which to add tags.
- `Tags`: The tags to add to the specified resource group. A tag is a string-to-string map of key-value pairs.

"""
tag(Arn, Tags; aws_config::AWSConfig=global_aws_config()) = resource_groups("PUT", "/resources/$(Arn)/tags", Dict{String, Any}("Tags"=>Tags); aws_config=aws_config)
tag(Arn, Tags, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("PUT", "/resources/$(Arn)/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Tags"=>Tags), args)); aws_config=aws_config)

"""
    UngroupResources()

Removes the specified resources from the specified group.

# Required Parameters
- `Group`: The name or the ARN of the resource group from which to remove the resources.
- `ResourceArns`: The ARNs of the resources to be removed from the group.

"""
ungroup_resources(Group, ResourceArns; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/ungroup-resources", Dict{String, Any}("Group"=>Group, "ResourceArns"=>ResourceArns); aws_config=aws_config)
ungroup_resources(Group, ResourceArns, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/ungroup-resources", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Group"=>Group, "ResourceArns"=>ResourceArns), args)); aws_config=aws_config)

"""
    Untag()

Deletes tags from a specified resource group.

# Required Parameters
- `Arn`: The ARN of the resource group from which to remove tags. The command removed both the specified keys and any values associated with those keys.
- `Keys`: The keys of the tags to be removed.

"""
untag(Arn, Keys; aws_config::AWSConfig=global_aws_config()) = resource_groups("PATCH", "/resources/$(Arn)/tags", Dict{String, Any}("Keys"=>Keys); aws_config=aws_config)
untag(Arn, Keys, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("PATCH", "/resources/$(Arn)/tags", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("Keys"=>Keys), args)); aws_config=aws_config)

"""
    UpdateGroup()

Updates the description for an existing group. You cannot update the name of a resource group.

# Optional Parameters
- `Description`: The new description that you want to update the resource group with. Descriptions can contain letters, numbers, hyphens, underscores, periods, and spaces.
- `Group`: The name or the ARN of the resource group to modify.
- `GroupName`: Don't use this parameter. Use Group instead.
"""
update_group(; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/update-group"; aws_config=aws_config)
update_group(args::AbstractDict{String, Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/update-group", args; aws_config=aws_config)

"""
    UpdateGroupQuery()

Updates the resource query of a group.

# Required Parameters
- `ResourceQuery`: The resource query to determine which AWS resources are members of this resource group.

# Optional Parameters
- `Group`: The name or the ARN of the resource group to query.
- `GroupName`: Don't use this parameter. Use Group instead.
"""
update_group_query(ResourceQuery; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/update-group-query", Dict{String, Any}("ResourceQuery"=>ResourceQuery); aws_config=aws_config)
update_group_query(ResourceQuery, args::AbstractDict{String, <:Any}; aws_config::AWSConfig=global_aws_config()) = resource_groups("POST", "/update-group-query", Dict{String, Any}(mergewith(_merge, Dict{String, Any}("ResourceQuery"=>ResourceQuery), args)); aws_config=aws_config)
